# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Version](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.1] - 2024-06-23
### Added
- `add_weight` feature.
- `add_activity` feature.
- `telemetry` feature.
### Fixed
- pypi release flow.